# HDT Adroit SocketCAN

This is a Python library for communicating the HDT Adroit robots using SocketCAN. This library was written by reverse engineering the provided ROS functions. At this time it is mostly undocumented except for the provided example.
